
function data = readgdif(dirpath)
%%
% Reads the data in a single stream from all sdif files in a directory
%
% data = mcreadgdif
% data = mcreadgdif(path)
% 
% 
% Easdif must be compiled and available in Matlab's search path for this to
% work






if nargin < 1
    dirpath = './';
    disp('Reading SDIF files in current directory')
else
    if dirpath(1) == '~'
        error('Please refrain from using the ''~'' character. Use the full path. (Will fix this later.)')
    end     
    if dirpath(length(dirpath)) ~= '/'
        dirpath(length(dirpath)+1) = '/';
    end 
    disp(['Reading SDIF files in ' dirpath])
end



a = dir([dirpath '*.sdif']);
data = struct('type', {},'filename', {});



for i = 1:length(a)
    [~, label] = fileparts(a(i).name);

   
    disp(['Reading:' label])

        
    data(i).filename  = [label '.sdif'];
    
    [tmp(i).file,tmp(i).head,tmp(i).dir] = Fsdifopen([dirpath  a(i).name]);
    [tmp(i).data,tmp(i).header,tmp(i).frame,tmp(i).matrix,tmp(i).dims] = Fsdifloadfile([dirpath  a(i).name]);
    Fsdifclose(tmp(i).file);
end


sound(0.3*sin((0:0.1:100)*pi),44100)
disp('done reading...')


disp('Parsing SDIF data into a better structure...')

for j=1:length(tmp)
    data(j).type  = 'GDIF data';

    for i = 1:length(tmp(j).head.TYP.MTD)
        eval(sprintf('data(%d).X%c%c%c=[];',j,tmp(j).head.TYP.MTD(i).msig(2:4)))
    end



    for i = 1:length(tmp(j).header)
       streamtype = sprintf('X%c%c%c',tmp(j).head.TYP.MTD(tmp(j).header(i,2)+1).msig(2:4));
       data(j).(streamtype)(size(data(j).(streamtype),1)+1,2:(length(tmp(j).data{i}(:))+1)) = tmp(j).data{i}(:);
       data(j).(streamtype)(size(data(j).(streamtype),1),1) = tmp(j).header(i,1);
            
            
     %  eval([sprintf('data(%d).%c%c%c%c(size(data(%d).%c%c%c%c,1)+1,2:(%d+1))',j,data(j).head.TYP.MTD(data(j).header(i,2)+1).msig,j,data(j).head.TYP.MTD(data(j).header(i,2)+1).msig,length(data(j).data{i}(:)))  '= data(' int2str(j) ').data{' int2str(i) '}(:)'';' ])
     %  eval([sprintf('data(%d).%c%c%c%c(size(data(%d).%c%c%c%c,1),1)',j,data(j).head.TYP.MTD(data(j).header(i,2)+1).msig,j,data(j).head.TYP.MTD(data(j).header(i,2)+1).msig)  '= data(' int2str(j) ').header(' int2str(i) ',1);' ])
    %   eval([sprintf('%c%c%c%c{length(%c%c%c%c)+1}',head.TYP.MTD(header(i,2)+1).msig,head.TYP.MTD(header(i,2)+1).msig)  '= data{' int2str(i) '};' ])    
    end
    
    sound(0.1*sin((0:(0.04+j/200):50)*pi),44100)
end

sound(0.3*sin((0:0.01:200).*(0.5:0.00005:1.5)).*sin(2:0.1:2002),44100)

end
